@@ -175,7 +175,7 @@ gconf_list_model_set_root_path (GConfListModel *model, const gchar *root_path)
 	}
 }
 
-static guint
+static GtkTreeModelFlags 
 gconf_list_model_get_flags (GtkTreeModel *tree_model)
 {
 	return 0;
